==> acornlib-1.21.5-r19-sources.jar: net/acoyt/acornlib/impl/block/PlushItem.java <==
package net.acoyt.acornlib.impl.block;

import net.acoyt.acornlib.impl.index.AcornBlocks;
import net.minecraft.class_10712;
import net.minecraft.class_124;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_2248;
import net.minecraft.class_2561;
import java.util.function.Consumer;

public class PlushItem extends class_1747 {
    public PlushItem(class_2248 block, class_1793 settings) {
        super(block, settings);
    }

    @SuppressWarnings("deprecation")
    public void method_67187(class_1799 stack, class_9635 context, class_10712 displayComponent, Consumer<class_2561> tooltip, class_1836 type) {
        if (stack.method_31574(AcornBlocks.ACO_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x8D78CD));
        }

        if (stack.method_31574(AcornBlocks.FESTIVE_ACO_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0xD54DAB));
        }

        if (stack.method_31574(AcornBlocks.CLOWN_ACO_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x1B84C4));
        }

        if (stack.method_31574(AcornBlocks.KIO_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x1d171d));
        }

        if (stack.method_31574(AcornBlocks.TOAST_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x852c24));
        }

        if (stack.method_31574(AcornBlocks.CHEM_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x47091d));
        }

    }
}

==> acornlib-1.21.8-r5-sources.jar: net/acoyt/acornlib/impl/block/PlushItem.java <==
package net.acoyt.acornlib.impl.block;

import net.acoyt.acornlib.impl.init.AcornBlocks;
import net.minecraft.class_10712;
import net.minecraft.class_124;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_2248;
import net.minecraft.class_2561;
import java.util.function.Consumer;

public class PlushItem extends class_1747 {
    public PlushItem(class_2248 block, class_1793 settings) {
        super(block, settings);
    }

    @SuppressWarnings("deprecation")
    public void method_67187(class_1799 stack, class_9635 context, class_10712 displayComponent, Consumer<class_2561> tooltip, class_1836 type) {
        if (stack.method_31574(AcornBlocks.ACO_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x8D78CD));
        }

        if (stack.method_31574(AcornBlocks.FESTIVE_ACO_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0xD54DAB));
        }

        if (stack.method_31574(AcornBlocks.CLOWN_ACO_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x1B84C4));
        }

        if (stack.method_31574(AcornBlocks.KIO_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x1d171d));
        }

        if (stack.method_31574(AcornBlocks.TOAST_PLUSH.method_8389())) {
            tooltip.accept(class_2561.method_43471(this.method_7876() + ".desc").method_27692(class_124.field_1067).method_54663(0x852c24));
        }

    }
}
